# ListAccessRequestsResponse

Response object for an access request query. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**access_requests** | [**list[AccessRequests]**](AccessRequests.md) | The matching AccessRequests objects | 
**limit** | **int** | Limit on the number of rows in the response | 
**previous_page_email** | **str** | User&#39;s email address | [optional] 
**next_page_email** | **str** | User&#39;s email address | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


